@@ -97,10 +97,12 @@ class PagamentoConfiguracaoBaseResource(PagamentoBaseResource):
 
     @property
     def pagamento_configuracao(self):
-        return FormaDePagamentoConfiguracao.objects.get(
-            conta_id=self.conta_id,
-            forma_pagamento_id=self.pagamento_id
-        )
+        if self.conta_id:
+            return FormaDePagamentoConfiguracao.objects.get(
+                conta_id=self.conta_id,
+                forma_pagamento_id=self.pagamento_id
+            )
+        return None
 
     def get(self, pagamento_id, conta_id):
         self.pagamento_id = pagamento_id
@@ -240,14 +242,18 @@ class FormaPagamentoConfiguracaoEnviarResource(PagamentoBaseResource):
             return {"erro": u"Servidor: {} - {}".format(ex, traceback.format_exc())}, 500
 
 
-class FormaPagamentoRetornoResource(PagamentoBaseResource):
-    def get(self, pagamento_id, tipo=None):
+class FormaPagamentoRetornoResource(PagamentoConfiguracaoBaseResource):
+    def post(self, pagamento_id, conta_id=None, tipo="retorno"):
+        return self.get(pagamento_id, conta_id, tipo)
+
+    def get(self, pagamento_id, conta_id=None, tipo="retorno"):
         self.pagamento_id = pagamento_id
+        self.conta_id = conta_id
         if self.retorno_tem_erro:
             return self.retorno()
         try:
-            registro = RegistrarPagamento(self.forma_de_pagamento.codigo, self.dados)
-            resultado = registro.processar(tipo)
+            registro = RegistrarPagamento(self.forma_de_pagamento.codigo, self.dados, tipo, self.pagamento_configuracao)
+            resultado = registro.processar()
             if "redirect" in resultado:
                 return redirect(resultado["redirect"], code=301)
             return resultado
