@@ -15,4 +15,6 @@ def registrar():
     api.add_resource(recursos.FormaPagamentoConfiguracaoEnviarResource, '/forma-pagamento/<int:pagamento_id>/configuracao/<int:conta_id>/pedido/<int:pedido_numero>/enviar')
     api.add_resource(recursos.FormaPagamentoRetornoResource,
                      '/forma-pagamento/<int:pagamento_id>/retorno',
-                     '/forma-pagamento/<int:pagamento_id>/retorno/<string:tipo>/')
+                     '/forma-pagamento/<int:pagamento_id>/retorno/<string:tipo>/',
+                     '/forma-pagamento/<int:pagamento_id>/conta/<int:conta_id>/retorno',
+                     '/forma-pagamento/<int:pagamento_id>/conta/<int:conta_id>/retorno/<string:tipo>/')
