@@ -91,6 +91,8 @@ class FormaDePagamento(models.FormaPagamento, Plugavel):
             "imagem_admin": self.imagem_admin,
             "imagem_loja": self.imagem_loja,
             "plano_indice": self.plano_indice,
+            "parcelas": [{"fator": float(parcela.fator), "numero_parcelas": parcela.numero_parcelas} for parcela in self.parcelas.all()],
+            "valor_minimo_parcela": float(self.valor_minimo_parcela or 0.0)
         }
         if com_configuracao:
             forma_pagamento["ativo_para_a_conta"] = self.pagamento_configuracao_ativo
